//go:build prod
// +build prod

package httpserver

import (
	"embed"
	"github.com/gorilla/mux"
	"io/fs"
	"net/http"
	"os"
)

// content holds our static web server content.
//go:embed static
var staticFiles embed.FS

type spaFileSystem struct {
	root http.FileSystem
}

func (spa *spaFileSystem) Open(name string) (http.File, error) {
	f, err := spa.root.Open(name)
	if os.IsNotExist(err) {
		return spa.root.Open("index.html")
	}
	return f, err
}

func initStatic(r *mux.Router) {
	staticFS, _ := fs.Sub(staticFiles, "static")
	r.PathPrefix("/").Handler(http.FileServer(&spaFileSystem{http.FS(staticFS)}))
}
